==> vips_7.10.10.orig.tar.gz: vips-7.10.10/doc/html/cppguide/images.pl <==
# LaTeX2HTML 2002-2-1 (1.70)
# Associate images original text with physical files.


$key = q/{figure}quote{preform{<verbatim_mark>verbatim35#preform{quote{{{{figure};FSF=1.6;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="665" HEIGHT="662" BORDER="0"
 SRC="|."$dir".q|img1.png"
 ALT="\begin{figure}\begin{quote}
\begin{verbatim}...">|; 

$key = q/{figure}quote{preform{<verbatim_mark>verbatim57#preform{quote{{{{figure};FSF=1.6;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="663" HEIGHT="529" BORDER="0"
 SRC="|."$dir".q|img9.png"
 ALT="\begin{figure}\begin{quote}
\begin{verbatim}/* Apply a scale and offset to eac...
...2.bandjoin( green2 ).bandjoin( blue2 ) );
}\end{verbatim}\end{quote}\end{figure}">|; 

$key = q/b^{*};MSF=1.6;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="20" HEIGHT="18" ALIGN="BOTTOM" BORDER="0"
 SRC="|."$dir".q|img7.png"
 ALT="$b^{*}$">|; 

$key = q/L^{*};MSF=1.6;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="24" HEIGHT="18" ALIGN="BOTTOM" BORDER="0"
 SRC="|."$dir".q|img5.png"
 ALT="$L^{*}$">|; 

$key = q/^{-1};MSF=1.6;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="23" HEIGHT="20" ALIGN="BOTTOM" BORDER="0"
 SRC="|."$dir".q|img4.png"
 ALT="$^{-1}$">|; 

$key = q/x,y;MSF=1.6;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="31" HEIGHT="32" ALIGN="MIDDLE" BORDER="0"
 SRC="|."$dir".q|img10.png"
 ALT="$x,y$">|; 

$key = q/a^{*};MSF=1.6;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="22" HEIGHT="18" ALIGN="BOTTOM" BORDER="0"
 SRC="|."$dir".q|img6.png"
 ALT="$a^{*}$">|; 

$key = q/L^{*}a^{*}b^{*};MSF=1.6;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="54" HEIGHT="18" ALIGN="BOTTOM" BORDER="0"
 SRC="|."$dir".q|img3.png"
 ALT="$L^{*}a^{*}b^{*}$">|; 

$key = q/{figure}quote{preform{<verbatim_mark>verbatim56#preform{quote{{{{figure};FSF=1.6;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="702" HEIGHT="834" BORDER="0"
 SRC="|."$dir".q|img8.png"
 ALT="\begin{figure}\begin{quote}
\begin{verbatim}/* Apply a scale and offset to eac...
...out, 3 ) )
return( -1 );return( 0 );
}\end{verbatim}\end{quote}\end{figure}">|; 

$key = q/{figure}quote{preform{<verbatim_mark>verbatim36#preform{quote{{{{figure};FSF=1.6;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="646" HEIGHT="490" BORDER="0"
 SRC="|."$dir".q|img2.png"
 ALT="\begin{figure}\begin{quote}
\begin{verbatim}...">|; 

1;

==> vips_7.10.17.orig.tar.gz: vips-7.10.17/doc/html/cppguide/images.pl <==
# LaTeX2HTML 2002-2-1 (1.70)
# Associate images original text with physical files.


$key = q/{figure}quote{preform{<verbatim_mark>verbatim35#preform{quote{{{{figure};FSF=1.6;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="665" HEIGHT="662" BORDER="0"
 SRC="|."$dir".q|img1.png"
 ALT="\begin{figure}\begin{quote}
\begin{verbatim}...">|; 

$key = q/{figure}quote{preform{<verbatim_mark>verbatim56#preform{quote{{{{figure};FSF=1.6;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="702" HEIGHT="834" BORDER="0"
 SRC="|."$dir".q|img8.png"
 ALT="\begin{figure}\begin{quote}
\begin{verbatim}/* Apply a scale and offset to eac...
...t, 3 ) )
return( -1 );return( 0 );
}\end{verbatim}
\end{quote}
\end{figure}">|; 

$key = q/L^{*};MSF=1.6;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="22" HEIGHT="14" ALIGN="BOTTOM" BORDER="0"
 SRC="|."$dir".q|img5.png"
 ALT="$L^{*}$">|; 

$key = q/{figure}quote{preform{<verbatim_mark>verbatim57#preform{quote{{{{figure};FSF=1.6;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="663" HEIGHT="529" BORDER="0"
 SRC="|."$dir".q|img9.png"
 ALT="\begin{figure}\begin{quote}
\begin{verbatim}/* Apply a scale and offset to eac...
...bandjoin( green2 ).bandjoin( blue2 ) );
}\end{verbatim}
\end{quote}
\end{figure}">|; 

$key = q/L^{*}a^{*}b^{*};MSF=1.6;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="52" HEIGHT="14" ALIGN="BOTTOM" BORDER="0"
 SRC="|."$dir".q|img3.png"
 ALT="$L^{*}a^{*}b^{*}$">|; 

$key = q/x,y;MSF=1.6;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="29" HEIGHT="30" ALIGN="MIDDLE" BORDER="0"
 SRC="|."$dir".q|img10.png"
 ALT="$x,y$">|; 

$key = q/b^{*};MSF=1.6;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="18" HEIGHT="14" ALIGN="BOTTOM" BORDER="0"
 SRC="|."$dir".q|img7.png"
 ALT="$b^{*}$">|; 

$key = q/{figure}quote{preform{<verbatim_mark>verbatim36#preform{quote{{{{figure};FSF=1.6;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="645" HEIGHT="490" BORDER="0"
 SRC="|."$dir".q|img2.png"
 ALT="\begin{figure}\begin{quote}
\begin{verbatim}...">|; 

$key = q/^{-1};MSF=1.6;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="21" HEIGHT="18" ALIGN="BOTTOM" BORDER="0"
 SRC="|."$dir".q|img4.png"
 ALT="$^{-1}$">|; 

$key = q/a^{*};MSF=1.6;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="20" HEIGHT="14" ALIGN="BOTTOM" BORDER="0"
 SRC="|."$dir".q|img6.png"
 ALT="$a^{*}$">|; 

1;
